<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://Techspawn.com
 * @since      1.0.0
 *
 * @package    Wamc
 * @subpackage Wamc/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Wamc
 * @subpackage Wamc/admin
 * @author     Techspawn <info@techspawn.com>
 */
class Wamc_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		require_once plugin_dir_path( __FILE__ ) . 'partials/wamc-cron-init.php';
		add_action('init', [$this, 'add_rewrite_rules']);
        add_action('template_redirect', [$this, 'rewrite_templates'], 1);

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		return;
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
		return;
	}



	public function wamc_register_menu_page()
	{	
		$link = '/wamc-admin-dashboard';
		add_menu_page(
			esc_html('WhatsCamp', $this->plugin_name . ''),
			esc_html('WhatsCamp', $this->plugin_name . ''),
			'edit_pages',
			$link,
			'',
			'dashicons-whatsapp',
			'65'
		);
	}

	


	public function wamc_register_setting(){
		// general admin settings
		add_settings_section(  
			$this->plugin_name . '_general_section',
			esc_html('Admin User Details', 'wamc'),
			array($this, $this->plugin_name . '_admin_section_callback'),
			$this->plugin_name . '_general'
		);
		add_settings_field(
			$this->plugin_name . '_whatsapp_api_connection_status', 
			esc_html('WhatsApp API Connection Status', 'wamc'),
			array($this, $this->plugin_name . '_whatsapp_api_connection_status_cb'),
			$this->plugin_name . '_general',
			$this->plugin_name . '_general_section', 
			array( 
				$this->plugin_name . '_whatsapp_api_connection_status' 
			)  
		); 

		add_settings_field(
			$this->plugin_name . '_bearer_token_whatsapp', 
			esc_html('WhatsApp Bearer Token', 'wamc'),
			array($this, $this->plugin_name . '_bearer_token_whatsapp_cb'),
			$this->plugin_name . '_general',
			$this->plugin_name . '_general_section', 
			array( 
				$this->plugin_name . '_bearer_token_whatsapp' 
			)  
		); 

		add_settings_field(
			$this->plugin_name . '_mobile_number_whatsapp', 
			esc_html('WhatsApp Mobile Number', 'wamc'),
			array($this, $this->plugin_name . '_mobile_number_whatsapp_cb'),
			$this->plugin_name . '_general',
			$this->plugin_name . '_general_section', 
			array(
				$this->plugin_name . '_mobile_number_whatsapp' 
			)  
		); 
		add_settings_field(
			$this->plugin_name . '_whatsapp_business_id', 
			esc_html('WhatsApp Business Account ID', 'wamc'),
			array($this, $this->plugin_name . '_whatsapp_business_id_cb'),
			$this->plugin_name . '_general',
			$this->plugin_name . '_general_section', 
			array(
				$this->plugin_name . '_whatsapp_business_id' 
			)  
		);
		add_settings_field(
			$this->plugin_name . '_whatsapp_business_mobile_number_id', 
			esc_html('WhatsApp Phone number ID', 'wamc'),
			array($this, $this->plugin_name . '_whatsapp_business_mobile_number_id_cb'),
			$this->plugin_name . '_general',
			$this->plugin_name . '_general_section', 
			array(
				$this->plugin_name . '_whatsapp_business_mobile_number_id'
			)  
		);

		//Register Hooks
		register_setting($this->plugin_name . '_general',$this->plugin_name . '_whatsapp_api_connection_status', 'esc_attr');
		register_setting($this->plugin_name . '_general',$this->plugin_name . '_bearer_token_whatsapp', 'esc_attr');
		register_setting($this->plugin_name . '_general',$this->plugin_name . '_mobile_number_whatsapp', 'esc_attr');
		register_setting($this->plugin_name . '_general',$this->plugin_name . '_whatsapp_business_id', 'esc_attr');
		register_setting($this->plugin_name . '_general',$this->plugin_name . '_whatsapp_business_mobile_number_id', 'esc_attr');

	}





	public function wamc_whatsapp_api_connection_status_cb(){
		$status = get_option("wamc_whatsapp_connection_status");
		require_once plugin_dir_path(__FILE__) . 'partials/wamc-api-functions.php';
		$_st = new Wamc_API_functions();
		$_st = $_st->wamc_get_wp_templates();

		$templateFetched = json_decode($_st)->data;
		if(!empty($templateFetched)){
			?><span class='wamc-connected'>
			<?php esc_html_e("Connected", 'wamc');
			?>
			</span><?php
		}else{
			?><span class='wamc-disconnected'>
			<?php esc_html_e("Disconnected", 'wamc');
			?>
			</span><?php
		}
	}

	public function wamc_bearer_token_whatsapp_cb($args) {  
		$option = get_option($args[0]);?>
		
		<textarea rows="1" cols="50" type="password" pattern="[A-Za-z0-9]" title="<?php esc_html_e('1000', 'wamc'); ?>" id="<?php echo esc_attr($args[0]); ?>" name="<?php echo esc_attr($args[0]); ?>" value="<?php esc_html_e($option, 'wamc'); ?>"><?php esc_html_e($option, 'wamc'); ?></textarea> 
		<label class="wamc_admin_descriptions">
			<?php echo esc_html('Bearer Token to be used for all other WhatsApp Business API calls, you can get it from Meta WhatsApp Manager.', 'wamc');
			?>
		</label>
		<?php
	}

	public function wamc_mobile_number_whatsapp_cb($args) {  
		$option = get_option($args[0]);
		?>
		<input type="number" id="<?php echo esc_attr($args[0]); ?>" name="<?php echo esc_attr($args[0]); ?>" value="<?php esc_html_e($option, 'wamc'); ?>" placeholder="<?php esc_html_e('123-456-7890', 'wamc');?>"/>
		<label class="wamc_admin_descriptions">
			<?php
		echo esc_html('Enter your WhatsApp mobile number for your business','wamc');
		?></label>
		<?php
	}

	public function wamc_whatsapp_business_id_cb($args) {  
		$option = get_option($args[0]);
		?>
		<input type="number" id="<?php echo esc_attr($args[0]); ?>" name="<?php echo esc_attr($args[0]); ?>" value="<?php esc_html_e($option, 'wamc'); ?>" placeholder="<?php esc_html_e('123456789000', 'wamc');?>"/>
		<label class="wamc_admin_descriptions">
			<?php
		echo esc_html('Enter your unique WhatsApp Business ID', 'wamc');
		?>
		</label>
		<?php
    
	}

	public function wamc_whatsapp_business_mobile_number_id_cb($args) {  
		$option = get_option($args[0]);
		?>
		<input type="number" id="<?php echo esc_attr($args[0]); ?>" name="<?php echo esc_attr($args[0]); ?>" value="<?php esc_html_e($option, 'wamc'); ?>" placeholder="<?php esc_html_e('Enter whatsapp number id', 'wamc');?>"/>
		<label class="wamc_admin_descriptions">
		<?php
		echo esc_html('Enter your WhatsApp Mobile Number ID','wamc');
		?>
		 </label>
		 <?php
	}



	// admin callbacks
	
	public function wamc_send_bulk_messages_callback(){
		$tempName = sanitize_text_field( wp_unslash($_POST['tempName']) );
		$userList = sanitize_text_field( wp_unslash($_POST['userList']) );
		if($tempName == "" ||$userList == ""){
			echo "empty";
			wp_die();
		}else{
				global $wpdb;
				$fetchContacts = $wpdb->get_results($wpdb->prepare("SELECT wamc_contacts_count FROM ".$wpdb->prefix."wamc_user_lists WHERE id = %s", $userList));	
				$contactList = $fetchContacts[0]->wamc_contacts_count;
				$contactList = json_decode($contactList);

				foreach($contactList as $k => $userID){
					$userData  = get_user_by( 'id', $userID );
					$userName  = $userData->user_login;
					$userMail  = $userData->user_email;
					$userFname = $userData->user_firstname;
					$userLname = $userData->user_lastname;
					$userDname = $userData->display_name;
					$userPhone = get_user_meta($userID, 'wamc_phone', true);
					$urCountry = get_user_meta($userID, 'wamc_country', true);
					//default country
					if($urCountry == ''){
						$urCountry = "IN";
					}
					require_once plugin_dir_path( __FILE__ ) . '/partials/wamc-helper-func.php';
					$userPhone = str_replace( array( '\'', '"', ',' , ';', '<', '>', '+', '-', '@' ), '', $userPhone);
					
					//get formatted mobile
					$mobileNumber = new WAMC_HELPER();
					$userPhone = $mobileNumber->get_formatted_mobile($userPhone, $urCountry);
					//shoot message
					require_once plugin_dir_path( __FILE__ ) . '/partials/wamc-shoot-msg.php';
					$sendMessage = new Wamc_Shoot();
					$sendMessage = $sendMessage->wamc_shoot_msg_user($userPhone, $tempName, $userID);
					
					$response_decode = get_object_vars(json_decode($sendMessage));
				
					if(!isset($response_decode['error'])){
						//insert message log
						$sentTO[] = $userPhone;
							
					}else{
						if(isset($response_decode['error'])){
						//insert message log
						$notSentTO[] = $userPhone;
						}
					}	
				}
				if(is_array($sentTO) && !empty($sentTO)){
				$countSentTO = count($sentTO);}else{
					$countSentTO = '';
				}
					$_return = array(
						"status" => "sent",
						"count"  => $countSentTO,
					);
					$_return = json_encode($_return);
					
				echo $_return;
			}
			wp_die();
	}

	//remove users from userlist
	public function wamc_remove_user_from_ul_callback(){
		global $wpdb;
		$table_name = $wpdb->prefix . 'wamc_user_lists'; 
		$userListID = sanitize_text_field( wp_unslash($_POST['ltID']) );
		$usrlistName = sanitize_text_field( wp_unslash($_POST['usrlistName']) );
		$userlistDesc = sanitize_text_field( wp_unslash($_POST['usrlistDes']) );
		$checkedUsers = wp_unslash($_POST['checkedUsers']);
		$isCheck = $_POST['isCheck'];
		
		

		$sql_query = $wpdb->prepare("SELECT id, wamc_user_list_name, wamc_contacts_count, wamc_list_description, wamc_list_created_on, wamc_list_status FROM $table_name WHERE id = %s", $userListID);
		$result = $wpdb->get_results($sql_query);

		$userlistArray = $result[0]->wamc_contacts_count;
		$jsonData = stripslashes(html_entity_decode($userlistArray));
		$userList = json_decode($jsonData,true);
		if($isCheck == "true"){
			$checkedUsers = $userList;
		}

		if(is_array($checkedUsers)&& !empty($checkedUsers) && !empty($userList)){
			$resultedArray = array_diff($userList, $checkedUsers);
		}else{
			$resultedArray = $userList;
		}

		//now update available fields
		$resultedArray = json_encode(array_values($resultedArray));
		$update_array = array(
			'wamc_user_list_name' => $usrlistName,
			'wamc_contacts_count' => $resultedArray,
			'wamc_list_description' => $userlistDesc,
			);
		$isUpdated = $wpdb->update($table_name, $update_array, array('id' => $userListID));
		if($isUpdated == "1"):
			echo "userl_updated";
		endif;
		wp_die();
	}

	//add user list 
	public function wamc_add_new_userlist_callback(){
		global $wpdb;
		$table_name = $wpdb->prefix . 'wamc_user_lists'; 
		$userlistName = wp_unslash($_POST['usrlistName']);
		$userlistDesc = wp_unslash($_POST['usrlistDes']);
		$userListCSV = $_POST['userListCSV'];
		$checkedUsers = wp_unslash($_POST['checkedUsers']);
		
		if(isset($checkedUsers) && $checkedUsers !=''):
			$userIDstoStore = json_encode($checkedUsers);
			
		endif;

		
		if(isset($userListCSV) && $userListCSV !=''):
			$jsonData = stripslashes(html_entity_decode($userListCSV));
			$userList = json_decode($jsonData,true);
			if(isset($userList)):
			foreach($userList as $key=> $value){
			
					
				$firstName = isset( $value['Firstname'] ) ? sanitize_text_field( wp_unslash( $value['Firstname'] ) ) : '';
				$Lastname = isset( $value['Lastname'] ) ? sanitize_text_field( wp_unslash( $value['Lastname'] ) ) : '';
				$Mobile = isset( $value['Mobile'] ) ? sanitize_text_field( wp_unslash( $value['Mobile'] ) ) : '';
				$Country = isset( $value['Country'] ) ? sanitize_text_field( wp_unslash( $value['Country'] ) ) : '';
				$Email = isset( $value['Email'] ) ? sanitize_text_field( wp_unslash( $value['Email'] ) ) : '';

				add_user_meta( $user_id, 'wamc_country', $Country, false );
				$user_data = get_user_by( 'email', $Email );
				$randomNum = substr(str_shuffle(str_repeat($x='0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ', ceil(15/strlen($x)) )),1,15);

				if(empty($user_data)){
					$userdata = array(
						'user_login' => $Email,
						'user_pass' => "$randomNum",
						'first_name' => $firstName,
						'last_name' => $Lastname,
						'user_email' => $Email,
						'user_registered' => date_default_timezone_get(),
						'display_name' => $firstName,
						'role' => 'subscriber',
						'phone' => $Mobile
					);

					$user_id = wp_insert_user( $userdata );
						if(is_wp_error($user_id)){
							$error = $user_id->get_error_message();
						}
					  	else{
							$userIDstoStore[] = $user_id;
							$userID = get_user_by('id', $user_id);
						}
						if (get_user_meta($user_id, 'wamc_phone', true)){
							update_user_meta( $user_id, 'wamc_phone', $Mobile, true );
							update_user_meta( $user_id, 'wamc_country', $Country, true );
						}else{
							add_user_meta( $user_id, 'wamc_phone', $Mobile, false );
							add_user_meta( $user_id, 'wamc_country', $Country, false );
						}
					}else{
						$userIDstoStore[] = $user_data->ID;
					}			
				}	
			endif;
			$userIDstoStore = json_encode($userIDstoStore);
		endif;


		
		$sql_query = $wpdb->prepare("SELECT COUNT(id) FROM $table_name WHERE wamc_user_list_name = %s", $userlistName);
		$count = $wpdb->get_var($sql_query);	
			if($userlistName == ""): 
				echo "in3";
				wp_die();
			endif;
			if($count>0):
				echo "in2";
				wp_die();
			endif;
		$isInserted = $wpdb->insert($table_name, array(
			'wamc_user_list_name' => $userlistName,
			'wamc_list_description' => $userlistDesc,
			'wamc_contacts_count' => $userIDstoStore,
			'wamc_list_status' => "Published",			
			));
		
		$response = ($isInserted == 1) ? "in1" : " in0";
		echo $response;
		
		wp_die();
	}

	public function wamc_update_userlist_otg_callback(){
	
		$fName = isset( $_REQUEST['fname'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['fname'] ) ) : '';
        $lName = isset( $_REQUEST['lname'] ) ?  sanitize_text_field( wp_unslash( $_REQUEST['lname'] ) ) : '';
        $mob = isset( $_REQUEST['wamcMob'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['wamcMob'] ) ) : '';
        $userID = isset( $_REQUEST['uid'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['uid'] ) ) : '';



		update_user_meta($userID, 'wamc_phone',  $mob);
		update_user_meta($userID, 'wamc_country', $countryCode);
		wp_update_user([
			'ID' => $userID, // this is the ID of the user you want to update.
			'first_name' => $fName,
			'last_name' => $lName,
		]);
		echo "save";
		wp_die();
	}

	public function wamc_add_to_userlist_single_callback(){
		global $wpdb;
		$fName = isset( $_REQUEST['fName'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['fName'] ) ) : '';
        $lName = isset( $_REQUEST['lName'] ) ?  sanitize_text_field( wp_unslash( $_REQUEST['lName'] ) ) : '';
        $mObile = isset( $_REQUEST['mObile'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['mObile'] ) ) : '';
        $cOuntry = isset( $_REQUEST['cOuntry'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['cOuntry'] ) ) : '';
        $uID = isset( $_REQUEST['uID'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['uID'] ) ) : '';

		
		$randomNum = substr(str_shuffle(str_repeat($x='0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ', ceil(15/strlen($x)) )),1,15);

				if(!empty($mObile)){
					$userdata = array(
						'user_login' => "$mObile",
						'user_pass' => "$randomNum",
						'first_name' => $fName,
						'last_name' => $lName,
						'role' => 'subscriber',
						'phone' => $mObile
					);

					$user_id = wp_insert_user( $userdata );
					}
					if(!empty($user_id)){
						$table_name = $wpdb->prefix."wamc_user_lists";
						$sql_query = $wpdb->prepare("SELECT id, wamc_user_list_name, wamc_contacts_count, wamc_list_description, wamc_list_created_on, wamc_list_status FROM $table_name WHERE id = %s", $uID);
						$result = $wpdb->get_results($sql_query);

						$userlistArray = $result[0]->wamc_contacts_count;
						$jsonData = stripslashes(html_entity_decode($userlistArray));
						$userList = json_decode($jsonData,true);
						$x = count($userList);
						$x++;
						$userArray = array( $x => $user_id );
						if(is_array($userList)&& !empty($userArray)){
							
							$resultedArray = array_merge($userList, $userArray);
							$resultArray = json_encode(array_values($resultedArray));

							$update_array = array(
								'wamc_contacts_count' => $resultArray,
							);
							$isUpdated = $wpdb->update($table_name, $update_array, array('id' => $uID));
						}
					}
					if(is_wp_error($user_id)){
						$error = $user_id->get_error_message();
						echo "_0";
					}
					  else{
						add_user_meta( $user_id, 'wamc_country', $cOuntry, false );
						add_user_meta( $user_id, 'wamc_phone', $mObile, false );
						echo "_1";
					}
		
		wp_die();
	}



	//add to current user list
	public function wamc_addtocurr_new_userlist_callback(){
		global $wpdb;
		$table_name = $wpdb->prefix . 'wamc_user_lists'; 
		$userlistName = wp_unslash($_POST['usrlistName']);
		$userlistDesc = wp_unslash($_POST['usrlistDes']);
		$userListCSV = $_POST['userListCSV'];
		$userListCSV = stripslashes(html_entity_decode($userListCSV));
		$userListCSV = json_decode($userListCSV);
		
		
		if(is_array($userListCSV) && !empty($userListCSV)):
			foreach($userListCSV as $key=> $value)
			{
				$firstName = isset( $value['Firstname'] ) ? sanitize_text_field( wp_unslash( $value['Firstname'] ) ) : '';
				$Lastname = isset( $value['Lastname'] ) ? sanitize_text_field( wp_unslash( $value['Lastname'] ) ) : '';
				$Mobile = isset( $value['Mobile'] ) ? sanitize_text_field( wp_unslash( $value['Mobile'] ) ) : '';
				$Country = isset( $value['Country'] ) ? sanitize_text_field( wp_unslash( $value['Country'] ) ) : '';
				$Email = isset( $value['Email'] ) ? sanitize_text_field( wp_unslash( $value['Email'] ) ) : '';

				add_user_meta( $user_id, 'wamc_country', $Country, false );
				$user_data = get_user_by( 'email', $Email );
				
				$randomNum = substr(str_shuffle(str_repeat($x='0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ', ceil(15/strlen($x)) )),1,15);
				if(empty($user_data)){
					$userdata = array(
						'user_login' => $Email,
						'user_pass' => "$randomNum",
						'first_name' => $firstName,
						'last_name' => $Lastname,
						'user_email' => $Email,
						'user_registered' => date_default_timezone_get(),
						'display_name' => $firstName,
						'role' => 'subscriber',
						'phone' => $Mobile
					);

					$user_id = wp_insert_user( $userdata );
						if(is_wp_error($user_id)){
							$error = $user_id->get_error_message();
						}
					  	else{
							$userIDstoStore[] = $user_id;
							$userID = get_user_by('id', $user_id);
						}
						if (get_user_meta($user_id, 'wamc_phone', true)){
							update_user_meta( $user_id, 'wamc_phone', $Mobile, true );
							update_user_meta( $user_id, 'wamc_country', $Country, true );
						}else{
							add_user_meta( $user_id, 'wamc_phone', $Mobile, false );
							add_user_meta( $user_id, 'wamc_country', $Country, false );
						}
					}else{
						$userIDstoStore[] = $user_data->ID;
					}			
				}

			
		
			
		endif;
		wp_die();
	}

	//add users to current by users module
	public function wamc_add_to_current_userlist_user_callback(){
		global $wpdb;
		$table_name = $wpdb->prefix . 'wamc_user_lists'; 
		$userListID = sanitize_text_field( wp_unslash($_POST['ltID']) );
		$usrlistName = sanitize_text_field( wp_unslash($_POST['usrlistName']) );
		$userlistDesc = sanitize_text_field( wp_unslash($_POST['usrlistDes']) );
		$checkedUsers = wp_unslash($_POST['checkedUsers']);
		$isCheck = $_POST['isCheck'];

		$sql_query = $wpdb->prepare("SELECT id, wamc_user_list_name, wamc_contacts_count, wamc_list_description, wamc_list_created_on, wamc_list_status FROM $table_name WHERE id = %s", $userListID);
		$result = $wpdb->get_results($sql_query);

		$userlistArray = $result[0]->wamc_contacts_count;
		$jsonData = stripslashes(html_entity_decode($userlistArray));
		$userList = json_decode($jsonData,true);
		if($isCheck == "true"){
			$checkedUsers = $userList;
		}
		if(is_array($checkedUsers)&& !empty($checkedUsers) && !empty($userList)){
			$resultedArray = array_merge($userList, $checkedUsers);
		}else{
			$resultedArray = $userList;
		}
		//now update available fields
		$resultedArray = json_encode(array_values($resultedArray));
		$update_array = array(
			'wamc_user_list_name' => $usrlistName,
			'wamc_contacts_count' => $resultedArray,
			'wamc_list_description' => $userlistDesc,
			);
		$isUpdated = $wpdb->update($table_name, $update_array, array('id' => $userListID));
		if($isUpdated == "1"):
			echo "userl_updated";
		endif;
		wp_die();
	}


	public function wamc_save_user_settings_callback(){
		$fName = isset( $_REQUEST['fName'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['fName'] ) ) : '';
        $lName = isset( $_REQUEST['lName'] ) ?  sanitize_text_field( wp_unslash( $_REQUEST['lName'] ) ) : '';
        $countryCode = isset( $_REQUEST['cc'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['cc'] ) ) : '';
        $mob = isset( $_REQUEST['mob'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['mob'] ) ) : '';
        $userID = isset( $_REQUEST['UID'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['UID'] ) ) : '';



		update_user_meta($userID, 'wamc_phone',  $mob);
		update_user_meta($userID, 'wamc_country', $countryCode);
		wp_update_user([
			'ID' => $userID, // this is the ID of the user you want to update.
			'first_name' => $fName,
			'last_name' => $lName,
		]);
		echo "save";
		wp_die();
        
	}
	//save admin settings 
	public function wamc_save_admin_settings_callback(){
		$waToken = isset( $_REQUEST['waToken'] ) ? update_option("wamc_bearer_token_whatsapp", sanitize_text_field( wp_unslash( $_REQUEST['waToken'] ) )) : '';
        $waPhone = isset( $_REQUEST['waPhone'] ) ? update_option("wamc_mobile_number_whatsapp", sanitize_text_field( wp_unslash( $_REQUEST['waPhone'] ) )) : '';
        $waBusID = isset( $_REQUEST['waBusID'] ) ? update_option("wamc_whatsapp_business_id", sanitize_text_field( wp_unslash( $_REQUEST['waBusID'] ) )) : '';
        $waBmbID = isset( $_REQUEST['waBmbID'] ) ? update_option("wamc_whatsapp_business_mobile_number_id", sanitize_text_field( wp_unslash( $_REQUEST['waBmbID'] ) )) : '';
        $waDlimt = isset( $_REQUEST['waDlimt'] ) ? update_option("wamc_daily_message_limit_whatsapp", sanitize_text_field( wp_unslash( $_REQUEST['waDlimt'] ) )) : '';
        $waTimez = isset( $_REQUEST['waTimez'] ) ? update_option("wamc_admin_timezone", sanitize_text_field( wp_unslash( $_REQUEST['waTimez'] ) )) : '';

		echo "save";
		wp_die();
	}

	//map templates

	public function wamc_update_template_options_callback(){

		global $wpdb;
		global $woocommerce;
		
		$wamc_template_id = sanitize_text_field($_POST['wamc_template_id']);
		$wamc_template_name = sanitize_text_field($_POST['wamc_template_name']);
		$wamc_head_param_count = sanitize_text_field($_POST['wamc_head_param_count']); // head param count
		$wamc_body_param_count = sanitize_text_field($_POST['wamc_body_param_count']); //body param count
		$wamc_head_text = sanitize_text_field($_POST['wamc_head_text']); //head text
		$wamc_body_text = sanitize_text_field($_POST['wamc_body_text']); //body text
		$wamc_head_params = sanitize_text_field($_POST['wamc_head_params']);
		$wamc_button_param_count = sanitize_text_field($_POST['wamc_button_param_count']);
	
		$wamc_body_params = json_encode($_POST['wamc_body_params']);
		$wamc_other_params = sanitize_text_field($_POST['wamc_language_params']);
	
		$table_name_2 = $wpdb->prefix . 'wamc_templates'; 
		$sql_query = $wpdb->prepare("SELECT COUNT(id) FROM $table_name_2 WHERE wamc_template_id = %s", $wamc_template_id);
		$count = $wpdb->get_var($sql_query);
		
						if($count == "0"){
						
							$wpdb->insert($table_name_2, array(
								'wamc_template_id' => $wamc_template_id,
								'wamc_template_name' => $wamc_template_name,
								'wamc_head_param_count' => $wamc_head_param_count,
								'wamc_body_param_count' => $wamc_body_param_count,
								'wamc_head_params' => $wamc_head_params,
								'wamc_body_params' => $wamc_body_params,
								'wamc_head_text' => $wamc_head_text,
								'wamc_body_text' => $wamc_body_text,
								'wamc_button_info' => $wamc_button_param_count,
								'wamc_other_params' => $wamc_other_params,
								
								));
						}else{
							
							$update_array = array(
								'wamc_template_name' => $wamc_template_name,
								'wamc_head_param_count' => $wamc_head_param_count,
								'wamc_body_param_count' => $wamc_body_param_count,
								'wamc_head_params' => $wamc_head_params,
								'wamc_body_params' => $wamc_body_params,
								'wamc_head_text' => $wamc_head_text,
								'wamc_body_text' => $wamc_body_text,
								'wamc_button_info' => $wamc_button_param_count,
								'wamc_other_params' => $wamc_other_params,
								);
	
							$wpdb->update($table_name_2, $update_array, array('wamc_template_id' => $wamc_template_id));
						
						}
						echo "1";
						wp_die();
	
	}
	
	//edit campaign settings 
	public function wamc_edit_campaign_callback(){
		global $wpdb;
		$table_name_2 = $wpdb->prefix."wamc_campaign";
		$campID = isset( $_REQUEST['campID'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['campID'] ) ) : '';
		$campName = isset( $_REQUEST['campName'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['campName'] ) ) : '';
		$campUList = isset( $_REQUEST['campUList'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['campUList'] ) ) : '';
		$campTname = isset( $_REQUEST['campTname'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['campTname'] ) ) : '';
		$campEdate = isset( $_REQUEST['campEdate'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['campEdate'] ) ) : '';
		
		$time = strtotime($campEdate);
		$sql_query = $wpdb->prepare("SELECT COUNT(id) FROM $table_name_2 WHERE wamc_campaign_name = %s", $campName);
		$count = $wpdb->get_var($sql_query);
			
			if($campName == "" || $campUList == "" || $campTname == "" || $campEdate == ""): 
				echo "camp_ublank";
				wp_die();
			endif;
			if($count>1):
				echo "camp_uexist";
				wp_die();
			endif;
		
		$update_array = array(
			'wamc_campaign_name' => $campName,
			'wamc_campaign_user_list' => $campUList,
			'wamc_campaign_template_id' => $campTname,
			'wamc_campaign_schedule' => $time,
			'wamc_campaign_meta' => current_datetime(),
			'wamc_campaign_status' => "active",
			);
		$isUpdated = $wpdb->update($table_name_2, $update_array, array('id' => $campID));
		if($isUpdated == "1"):
			echo "camp_updated";
		endif;
		wp_die();
	}

	//delete userlist
	public function wamc_delete_userlist_callback(){
		$uListID = sanitize_text_field( wp_unslash($_POST['uListID']) );
		global $wpdb;
		$table = $wpdb->prefix."wamc_user_lists";
		$isDeleted = $wpdb->delete( $table, array( 'id' => $uListID ) );
		echo "$isDeleted";
		wp_die();
	}

	// remove USER from USERLIST
	public function wamc_delete_user_callback(){
		global $wpdb;
		$uListID = sanitize_text_field( wp_unslash($_POST['uListID']) );
		$userListID = sanitize_text_field( wp_unslash($_POST['userListID']) );
		$table_name = $wpdb->prefix."wamc_user_lists";
		$sql_query = $wpdb->prepare("SELECT id, wamc_user_list_name, wamc_contacts_count, wamc_list_description, wamc_list_created_on, wamc_list_status FROM $table_name WHERE id = %s", $userListID);
		$result = $wpdb->get_results($sql_query);

		$userlistArray = $result[0]->wamc_contacts_count;
		$jsonData = stripslashes(html_entity_decode($userlistArray));
		$userList = json_decode($jsonData,true);
		$uListID = array( 0 => "$uListID");
		if(is_array($userList)&& !empty($uListID)){
			
			$resultedArray = array_diff($userList, $uListID);
			$resultArray = json_encode(array_values($resultedArray));

			$update_array = array(
				'wamc_contacts_count' => $resultArray,
			);
			$isUpdated = $wpdb->update($table_name, $update_array, array('id' => $userListID));
		}
		if($isUpdated == "1"):
			echo "deleted";
		endif;
		if(!isset($isUpdated)):
			echo "error";
		endif;
		wp_die();
	}
	
	//delete campaign settings 
	public function wamc_delete_campaign_callback(){
		$campID = sanitize_text_field( wp_unslash($_POST['campID']) );
		global $wpdb;
		$table = $wpdb->prefix."wamc_campaign";
		$isDeleted = $wpdb->delete( $table, array( 'id' => $campID ) );
		echo "$isDeleted";
		wp_die();
	}

	// edit userlist
	public function wamc_update_userlist_callback(){

		global $wpdb;
		$ltName = isset( $_REQUEST['ltName'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['ltName'] ) ) : '';
		$ltDesc = isset( $_REQUEST['ltDesc'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['ltDesc'] ) ) : '';
		$ltID = isset( $_REQUEST['ltID'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['ltID'] ) ) : '';
		$table_name_2 = $wpdb->prefix.'wamc_user_lists';
		$update_array = array(
			'wamc_user_list_name' => $ltName,
			'wamc_list_description' => $ltDesc,
			);
		$isUpdated = $wpdb->update($table_name_2, $update_array, array('id' => $ltID));
		if($isUpdated == "1"):
			echo "camp_updated";
		endif;
		wp_die();
	
	}


	public function wamc_add_new_campaign_callback(){
		
		$campName = isset( $_REQUEST['campName'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['campName'] ) ) : '';
		$campUList = isset( $_REQUEST['campUList'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['campUList'] ) ) : '';
		$campTname = isset( $_REQUEST['campTname'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['campTname'] ) ) : '';
		$campEdate = isset( $_REQUEST['campEdate'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['campEdate'] ) ) : '';
		$time = strtotime($campEdate);
		
		global $wpdb;
		$table_name = $wpdb->prefix . 'wamc_campaign'; 
		$sql_query = $wpdb->prepare("SELECT COUNT(id) FROM $table_name WHERE wamc_campaign_name = %s", $campName);
		$count = $wpdb->get_var($sql_query);	
			if($campName == "" || $campUList == "" || $campTname == "" || $campEdate == ""): 
				echo "camp_blank";
				wp_die();
			endif;
			if($count>0):
				echo "camp_exist";
				wp_die();
			endif;
		$isInserted = $wpdb->insert($table_name, array(
			'wamc_campaign_name' => $campName,
			'wamc_campaign_user_list' => $campUList,
			'wamc_campaign_template_id' => $campTname,
			'wamc_campaign_schedule' => $time,			
			'wamc_campaign_status' => 'active',			
			));
		
		$response = ($isInserted == 1) ? "camp_added" : " camp_notadded";
		echo $response;
		wp_die();
		
	}

	
	public function add_rewrite_rules()
    {
        add_rewrite_rule('^wamc-admin-dashboard/?$', 'index.php?wamc-admin-dashboard=true', 'top');
        add_rewrite_rule('^wamc-create-userlist/?$', 'index.php?wamc-create-userlist=true', 'top');
        add_rewrite_rule('^wamc-userlist/?$', 'index.php?wamc-userlist=true', 'top');
        add_rewrite_rule('^wamc-campaigns/?$', 'index.php?wamc-campaigns=true', 'top');
        add_rewrite_rule('^wamc-bulk-message/?$', 'index.php?wamc-bulk-message=true', 'top');
        add_rewrite_rule('^wamc-admin-setting/?$', 'index.php?wamc-admin-setting=true', 'top');
        add_rewrite_rule('^wamc-manage-template/?$', 'index.php?wamc-manage-template=true', 'top');
        add_rewrite_rule('^wamc-sign-in/?$', 'index.php?wamc-sign-in=true', 'top');
        add_rewrite_rule('^wamc-sign-up/?$', 'index.php?wamc-sign-up=true', 'top');

    }
	public function rewrite_templates()
    {
        if (strpos($_SERVER['REQUEST_URI'], "/wamc-admin-dashboard") !== false){
			if ( current_user_can( 'manage_options' ) ) {
            include_once WAMC_DIR_PATH . '/wamc-panel/wamc-dashboard.php';
			}
            exit;
            }
		if (strpos($_SERVER['REQUEST_URI'], "/wamc-create-userlist") !== false){
			if ( current_user_can( 'manage_options' ) ) {
			include_once WAMC_DIR_PATH . '/wamc-panel/wamc-create-user-list.php';
			}
			exit;
			}
		if (strpos($_SERVER['REQUEST_URI'], "/wamc-userlist") !== false){
			if ( current_user_can( 'manage_options' ) ) {
			include_once WAMC_DIR_PATH . '/wamc-panel/wamc-user-list.php';
			}
			exit;
			}
		if (strpos($_SERVER['REQUEST_URI'], "/wamc-campaigns") !== false){
			if ( current_user_can( 'manage_options' ) ) {
			include_once WAMC_DIR_PATH . '/wamc-panel/wamc-campaigns.php';
			}
			exit;
			}
		if (strpos($_SERVER['REQUEST_URI'], "/wamc-bulk-message") !== false){
			if ( current_user_can( 'manage_options' ) ) {
			include_once WAMC_DIR_PATH . '/wamc-panel/wamc-bulk-message.php';
			}
			exit;
			}
		if (strpos($_SERVER['REQUEST_URI'], "/wamc-admin-setting") !== false){
			if ( current_user_can( 'manage_options' ) ) {
			include_once WAMC_DIR_PATH . '/wamc-panel/wamc-admin-setting.php';
			}
			exit;
			}
		if (strpos($_SERVER['REQUEST_URI'], "/wamc-sign-in") !== false){
			if ( current_user_can( 'manage_options' ) ) {
			include_once WAMC_DIR_PATH . '/wamc-panel/wamc-sign-in.php';
			}
			exit;
			}
		if (strpos($_SERVER['REQUEST_URI'], "/wamc-sign-up") !== false){
			if ( current_user_can( 'manage_options' ) ) {
			include_once WAMC_DIR_PATH . '/wamc-panel/wamc-sign-up.php';
			}
			exit;
			}

		if (strpos($_SERVER['REQUEST_URI'], "/wamc-manage-template") !== false){
			if ( current_user_can( 'manage_options' ) ) {
			include_once WAMC_DIR_PATH . '/wamc-panel/wamc-manage-template.php';
			}
			exit;
			}
    }


	public function wamc_change_404_title($title) {
		if (is_404()) {
			$url = $_SERVER['REQUEST_URI'];
			$path = parse_url($url, PHP_URL_PATH);
			$segments = explode('/', rtrim($path, '/'));
			$__URL = end($segments);	
	
			switch($__URL){
				case "wamc-admin-dashboard":
					return 'Admin Dashboard';
				case "wamc-userlist":
					return 'Userlist';
				case "wamc-campaigns":
					return 'Campaigns';
				case "wamc-bulk-message":
					return 'Bulk Messaging';
				case "wamc-admin-setting":
					return 'Admin Settings';
				case "wamc-manage-template":
					return 'Manage Templates';
				default:
					return 'Page Not Found';
	
			}
		}
		return $title;
	}

}
