<?php

/**
 * Fired during plugin activation
 *
 * @link       https://Techspawn.com
 * @since      1.0.0
 *
 * @package    Wamc
 * @subpackage Wamc/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Wamc
 * @subpackage Wamc/includes
 * @author     Techspawn <info@techspawn.com>
 */
class Wamc_Activator {

	/**
	 * Activater Scripts 
	 *
	 * We are using this to create datatables
	 *
	 * @since    1.0.0
	 */
	public static function activate() {
		global $wpdb; 
		$table_name_1 = $wpdb->prefix . 'wamc_user_lists';

		//charsets
		$charset_collate = $wpdb->get_charset_collate();
		if(strtolower($wpdb->get_var( "show tables like '$table_name_1'" )) != strtolower($table_name_1) ):
			$tbl = "CREATE TABLE $table_name_1 (
				`id`                  BIGINT(20) NOT NULL auto_increment,
				`wamc_user_list_name`         VARCHAR(100) NULL DEFAULT NULL,
				`wamc_contacts_count`      LONGTEXT NULL DEFAULT NULL,
				`wamc_list_description`  LONGTEXT NULL DEFAULT NULL,
				`wamc_list_created_on` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
				`wamc_list_status`  VARCHAR(100) NULL DEFAULT NULL,
				PRIMARY KEY (`id`)
				)$charset_collate;";
				include_once ABSPATH . '/wp-admin/includes/upgrade.php';
				dbDelta($tbl);
			endif;

			$wamc_campaign = $wpdb->prefix . 'wamc_campaign';

		//charsets
		$charset_collate = $wpdb->get_charset_collate();
		if(strtolower($wpdb->get_var( "show tables like '$wamc_campaign'" )) != strtolower($wamc_campaign) ):
			$campaign_tbl = "CREATE TABLE $wamc_campaign (
				`id`                  BIGINT(20) NOT NULL auto_increment,
				`wamc_campaign_name`         VARCHAR(100) NULL DEFAULT NULL,
				`wamc_campaign_condition`      LONGTEXT NULL DEFAULT NULL,
				`wamc_campaign_user_list`  LONGTEXT NULL DEFAULT NULL,
				`wamc_campaign_template_id`  LONGTEXT NULL DEFAULT NULL,
				`wamc_campaign_schedule`  LONGTEXT NULL DEFAULT NULL,
				`wamc_campaign_meta`  LONGTEXT NULL DEFAULT NULL,
				`wamc_campaign_created_on` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
				`wamc_campaign_status`  VARCHAR(100) NULL DEFAULT NULL,
				PRIMARY KEY (`id`)
				)$charset_collate;";
				include_once ABSPATH . '/wp-admin/includes/upgrade.php';
				dbDelta($campaign_tbl);
			endif;

		$table_name_2 = $wpdb->prefix.'wamc_templates';
		if(strtolower($wpdb->get_var( "show tables like '$table_name_2'" )) != strtolower($table_name_2) ):
			$tbl = "CREATE TABLE $table_name_2 (
				`id`                  BIGINT(20) NOT NULL auto_increment,
				`wamc_template_id`         VARCHAR(50) NULL DEFAULT NULL,
				`wamc_template_name`         VARCHAR(50) NULL DEFAULT NULL,
				`wamc_head_param_count`      INT NOT NULL DEFAULT '0',
				`wamc_body_param_count`  INT NOT NULL DEFAULT '0',
				`wamc_head_params` 	LONGTEXT NULL DEFAULT NULL,
				`wamc_body_params` 	 LONGTEXT NULL DEFAULT NULL,
				`wamc_head_text`       VARCHAR(50) NULL DEFAULT NULL,
				`wamc_body_text`    VARCHAR(500) NULL DEFAULT NULL,
				`wamc_button_info`           LONGTEXT NULL DEFAULT NULL,
				`wamc_other_params`     LONGTEXT NULL DEFAULT NULL,
				`wamc_updated_date_time`  DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
				PRIMARY KEY (`id`)
				)$charset_collate;";
				include_once ABSPATH . '/wp-admin/includes/upgrade.php';
				dbDelta($tbl);
		endif;

	}

}
