<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://Techspawn.com
 * @since      1.0.0
 *
 * @package    Wamc
 * @subpackage Wamc/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Wamc
 * @subpackage Wamc/public
 * @author     Techspawn <info@techspawn.com>
 */
class Wamc_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
	


	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */	
	public function enqueue_styles() {

		global $wp_scripts, $wp_styles;
		$url = $_SERVER['REQUEST_URI'];
		$path = parse_url($url, PHP_URL_PATH);
		$segments = explode('/', rtrim($path, '/'));
		$__URL = end($segments);	
		if($__URL == "wamc-admin-dashboard" || $__URL == "wamc-userlist" || $__URL == "wamc-campaigns"|| $__URL == "wamc-bulk-message" || $__URL == "wamc-admin-setting" || $__URL == "wamc-manage-template"):
			foreach($wp_styles->registered as $registered){
				wp_deregister_style($registered->handle);
			}
			wp_enqueue_style( 'wamc-custom', plugin_dir_url( __FILE__ ) . 'dashboard/css/wamc-dashboard.css', array(), $this->version, 'all' );

			wp_enqueue_style( 'wamc-dashboard', plugin_dir_url( __FILE__ ) . 'dashboard/css/dashboard.css', array(), $this->version, 'all' );

			wp_enqueue_style( 'jquery-modal', plugin_dir_url( __FILE__ ) . 'dashboard/css/jquery.modal.min.css', array(), $this->version, 'all' );
			
			wp_enqueue_style( 'select2', plugin_dir_url( __FILE__ ) . 'dashboard/css/select2.min.css', array(), $this->version, 'all' );

			wp_enqueue_style( 'fontawesome', plugin_dir_url( __FILE__ ) . 'dashboard/css/all.min.css');

			wp_enqueue_style( 'datepicker', plugin_dir_url( __FILE__ ) . 'dashboard/css/flatpickr.min.css', array(), $this->version, 'all' );
			
			wp_enqueue_style( "datatables", plugin_dir_url( __FILE__ ) . 'dashboard/css/jquery.dataTables.min.css', array(), $this->version, 'all' );

			wp_enqueue_style( "jquery-buttons", plugin_dir_url( __FILE__ ) . 'dashboard/css/buttons.dataTables.min.css', array(), $this->version, 'all' );

		endif;
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/wamc-public.css', array(), $this->version, 'all' );
		
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		global $wp_scripts, $wp_styles;
		$url = $_SERVER['REQUEST_URI'];
		$path = parse_url($url, PHP_URL_PATH);
		$segments = explode('/', rtrim($path, '/'));
		$__URL = end($segments);	
		if($__URL == "wamc-admin-dashboard" || $__URL == "wamc-userlist" || $__URL == "wamc-campaigns" || $__URL == "wamc-bulk-message" || $__URL == "wamc-admin-setting" || $__URL == "wamc-manage-template"):
			foreach($wp_styles->registered as $registered){
				if($registered->handle != "jquery-ui-core-js" || $registered->handle != "jquery-ui-mouse-js" || $registered->handle != "jquery-ui-draggable-js" || $registered->handle != "jquery-ui-slider-js")
				wp_deregister_script($registered->handle);
			}
			wp_enqueue_script( 'jquery-advance', plugin_dir_url( __FILE__ ) . 'dashboard/js/jquery.min.js', array( 'jquery' ), $this->version, false );

			wp_enqueue_script( 'flatpicker', plugin_dir_url( __FILE__ ) . 'dashboard/js/flatpickr.js', array( 'jquery' ), $this->version, false );

			wp_enqueue_script( 'jquery-modal', plugin_dir_url( __FILE__ ) . 'dashboard/js/jquery.modal.min.js', array( 'jquery' ), $this->version, false );
			
			wp_enqueue_script( 'wamc-dashboard', plugin_dir_url( __FILE__ ) . 'dashboard/js/dashboard.js', array( 'jquery' ), $this->version, false );

			wp_enqueue_script( 'wamc-add-new-userlist', plugin_dir_url( __FILE__ ) . 'dashboard/js/wamc-add-new-userlist.js', array( 'jquery' ), $this->version, false );
			wp_localize_script('wamc-add-new-userlist', $this->plugin_name, array('ajaxurl' => admin_url('admin-ajax.php'), 'nonce' => wp_create_nonce('ajax_nonce_can')));

			wp_enqueue_script( "select2", plugin_dir_url( __FILE__ ) . 'dashboard/js/select2.js', array( 'jquery' ), $this->version, false );
			wp_enqueue_script( "select22", plugin_dir_url( __FILE__ ) . 'dashboard/js/select2.min.js', array( 'jquery' ), $this->version, false );

			wp_enqueue_script( 'sweetalert', plugin_dir_url( __FILE__ ) . 'dashboard/js/sweetalert2.js', array( 'jquery' ), $this->version, false );

			wp_enqueue_script( 'bootstrap', plugin_dir_url( __FILE__ ) . 'dashboard/js/bootstrap.bundle.min.js', array( 'jquery' ), $this->version, false );

			wp_enqueue_script( 'bootstrap2', plugin_dir_url( __FILE__ ) . 'dashboard/js/bootstrap.min.js', array( 'jquery' ), $this->version, false );

			wp_enqueue_script( 'popper', plugin_dir_url( __FILE__ ) . 'dashboard/js/popper.min.js', array( 'jquery' ), $this->version, false );

			wp_enqueue_script('datatables', plugin_dir_url( __FILE__ ) . 'dashboard/js/jquery.dataTables.min.js', array( 'jquery' ), $this->version, false );

			wp_enqueue_script('jquery-buttons', plugin_dir_url( __FILE__ ) . 'dashboard/js/dataTables.buttons.min.js', array( 'jquery' ), $this->version, false );

			wp_enqueue_script( 'wamc-chart', plugin_dir_url( __FILE__ ) . 'dashboard/js/plugins/chartjs.min.js', array( 'jquery' ), $this->version, false );

			wp_enqueue_script( 'wamc-chart-custom', plugin_dir_url( __FILE__ ) . 'dashboard/js/wamc-chart.js', array( 'jquery' ), $this->version, false );
			

			
		endif;
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/wamc-public.js', array( 'jquery' ), $this->version, false );
	}
	

}
