<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://Techspawn.com
 * @since             1.0.0
 * @package           Wamc
 *
 * @wordpress-plugin
 * Plugin Name:       WhatsCamp – WhatsApp Marketing Campaign for WordPress
 * Plugin URI:        https://techspawn.com
 * Description:       WhatsCamp is a WhatsApp marketing tool using which you can create message campaigns and send it to your target audience. 
 * Version:           1.0.1
 * Author:            20script
 * Author URI:        https://www.20script.ir
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       wamc
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'WAMC_VERSION', '1.0.0' );
define( 'WAMC_DOMAIN', 'wamc' );
define( 'WAMC_FILE', __FILE__ );
define( 'WAMC_DIR_PATH', __DIR__ );
define( 'WAMC_ROOT', dirname( plugin_basename( WAMC_FILE ) ) );



add_action('init', 'wamc_init');
function wamc_init(){
	$timeZone =  get_option('wamc_admin_timezone');
	if($timeZone != "-1"){
		date_default_timezone_set("$timeZone");
	}
}
/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-wamc-activator.php
 */
function wamc_activate() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wamc-activator.php';
	Wamc_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-wamc-deactivator.php
 */
function wamc_deactivate() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wamc-deactivator.php';
	Wamc_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'wamc_activate' );
register_deactivation_hook( __FILE__, 'wamc_deactivate' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-wamc.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_wamc() {

	$plugin = new Wamc();
	$plugin->run();

}
run_wamc();
